# synthe

<hr>

A Python package for
**synthetic data generation/simulation**

![PyPI](https://img.shields.io/pypi/v/synthe) [![PyPI - License](https://img.shields.io/pypi/l/synthe)](LICENSE) [![Downloads](https://pepy.tech/badge/synthe)](https://pepy.tech/project/synthe) 
[![Documentation](https://img.shields.io/badge/documentation-is_here-green)](https://techtonique.github.io/synthe/)


## Features

- Generate synthetic data that preserves the statistical properties of the original dataset.
- Generate realistic synthetic data for various applications.

See [examples](examples/) for usage.

## Credits

This package was created with [Cookiecutter](https://github.com/audreyfeldroy/cookiecutter) and the [audreyfeldroy/cookiecutter-pypackage](https://github.com/audreyfeldroy/cookiecutter-pypackage) project template.
